@@ -4,7 +4,7 @@ package Data::Record::Serialize::Encode::ddump;
 
 use Moo::Role;
 
-our $VERSION = '1.02'; # TRIAL
+our $VERSION = '1.03'; # TRIAL
 
 use Scalar::Util;
 use Data::Dumper;
@@ -73,7 +73,7 @@ around BUILD => sub {
 
     for my $mth ( keys  %config ) {
         my $code = $ddump->can( $mth )
-          or error( '::parameter', "$mth is not a Data::Dump configuration variable" );
+          or error( '::parameter', "$mth is not a Data::Dumper configuration variable" );
         $code->( $ddump, $config{$mth});
     }
     return;
@@ -112,7 +112,7 @@ Data::Record::Serialize::Encode::ddump - encoded a record using Data::Dumper
 
 =head1 VERSION
 
-version 1.02
+version 1.03
 
 =head1 SYNOPSIS
 
